# Generated by Django 2.2.24 on 2021-11-15 13:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0008_auto_20201008_1430'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='codefragment',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AlterModelOptions(
            name='helloworld',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AddField(
            model_name='codefragment',
            name='description_en',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='codefragment',
            name='description_fr',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='codefragment',
            name='title_en',
            field=models.CharField(max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='codefragment',
            name='title_fr',
            field=models.CharField(max_length=255, null=True),
        ),
    ]



from modeltranslation.translator import translator, TranslationOptions
from .models import CodeFragment

class EditorTranslationOptions(TranslationOptions):
    fields = ('title', 'description')

translator.register(CodeFragment, EditorTranslationOptions)



# Generated by Django 2.2.16 on 2020-10-08 14:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0007_auto_20191218_1033'),
    ]

    operations = [
        migrations.AddField(
            model_name='codefragment',
            name='allow_create_backlink',
            field=models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save'),
        ),
        migrations.AddField(
            model_name='codefragment',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AddField(
            model_name='helloworld',
            name='allow_create_backlink',
            field=models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save'),
        ),
        migrations.AddField(
            model_name='helloworld',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AddField(
            model_name='user',
            name='allow_create_backlink',
            field=models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save'),
        ),
        migrations.AddField(
            model_name='user',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
    ]



# Generated by Django 2.2.24 on 2021-11-15 14:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0009_auto_20211115_1449'),
    ]

    operations = [
        migrations.AlterField(
            model_name='codefragment',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='codefragment',
            name='title',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='codefragment',
            name='title_en',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='codefragment',
            name='title_fr',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
